Skip to contents

A data dictionary for the gcdf3_dataset

Usage

gcdf3_data_dictionary

Format

A tibble with 126 rows and 4 variables:

column_name

chr The name of the column in the gcdf3_dataset. It is the snake_case version of the AidData variable name shown in field_name, used because it is easier to work with in R.

column_class

chr The column's data type.

field_name

chr The name of the variable from the AidData dataset.

description

chr The variable's definition.