Skip to contents

A tibble providing standardized country names, iso3c codes, and a column to filter between country-specific and regional projects. Country names are standardized using countrycode::countryname().

Usage

gcdf3_standardized_countrynames

Format

A tibble with 154 rows and 4 variables:

recipient

chr The loan recipient listed in the recipient column of the gcdf3_dataset. See the gcdf3_data_dictionary for more details.

country_name

chr The standardized country name provided by countrycode::countryname(). When the project is regional, the region listed in recipient is used.

iso3c

chr The iso3c country code This can be helpful for joining other country features. Projects where the recipient is a region have NA values.

country_or_regional

chr A column to allow filtering between country-based lending and regional lending.