Skip to contents

get_gcdf3_dataset() makes it easy to load AidData's Global Chinese Development Finance Dataset, Version 3.0 (GCDF 3.0). By default, the function adds standardized country names that make it easier to merge it with other datasets. The standardized country names are described in the documentation for gcdf3_standardized_countrynames. Setting standardized_countrynames = FALSE is equivalent to simply calling the gcdf3_dataset data object. The data definitions are available in the gcdf3_data_dictionary.

Usage

get_gcdf3_dataset(standardized_countrynames = TRUE)

Arguments

standardized_countrynames

set to TRUE by default, this argument attaches standardized country names to make it easier to join the dataset with other datasets.

Value

get_gcdf3_dataset() returns a tibble with 20,985 observations.

Examples

# returns the GCDF 3.0 dataset, with standardized country names
get_gcdf3_dataset()
#> # A tibble: 20,985 × 129
#>    country_name iso3c country_or_regional aid_data_record_id
#>    <chr>        <chr> <chr>                            <int>
#>  1 Afghanistan  AFG   country                          94556
#>  2 Afghanistan  AFG   country                          94564
#>  3 Afghanistan  AFG   country                          94565
#>  4 Afghanistan  AFG   country                          94567
#>  5 Afghanistan  AFG   country                          94568
#>  6 Afghanistan  AFG   country                          94613
#>  7 Afghanistan  AFG   country                          94619
#>  8 Afghanistan  AFG   country                          95312
#>  9 Afghanistan  AFG   country                          95322
#> 10 Afghanistan  AFG   country                          95323
#> # ℹ 20,975 more rows
#> # ℹ 125 more variables: recommended_for_aggregates <chr>,
#> #   aid_data_parent_id <chr>, umbrella <chr>, financier_country <chr>,
#> #   recipient <chr>, recipient_iso_3 <chr>, recipient_region <chr>,
#> #   commitment_year <int>, implementation_start_year <int>,
#> #   completion_year <int>, title <chr>, description <chr>,
#> #   staff_comments <chr>, status <chr>, intent <chr>, flow_type <chr>, …

# returns the GCDF 3.0 dataset as-is.
get_gcdf3_dataset(standardized_countrynames = FALSE)
#> # A tibble: 20,985 × 126
#>    aid_data_record_id recommended_for_aggregates aid_data_parent_id umbrella
#>                 <int> <chr>                      <chr>              <chr>   
#>  1              94556 Yes                        NA                 No      
#>  2              94564 Yes                        NA                 No      
#>  3              94565 Yes                        NA                 No      
#>  4              94567 Yes                        NA                 No      
#>  5              94568 Yes                        NA                 No      
#>  6              94613 Yes                        NA                 No      
#>  7              94619 Yes                        NA                 No      
#>  8              95312 No                         NA                 No      
#>  9              95322 Yes                        NA                 No      
#> 10              95323 Yes                        NA                 No      
#> # ℹ 20,975 more rows
#> # ℹ 122 more variables: financier_country <chr>, recipient <chr>,
#> #   recipient_iso_3 <chr>, recipient_region <chr>, commitment_year <int>,
#> #   implementation_start_year <int>, completion_year <int>, title <chr>,
#> #   description <chr>, staff_comments <chr>, status <chr>, intent <chr>,
#> #   flow_type <chr>, flow_type_simplified <chr>,
#> #   oecd_oda_concessionality_threshold <dbl>, flow_class <chr>, …

# the latter is equivalent to simply calling the [gcdf3_dataset] data object
gcdf3_dataset
#> # A tibble: 20,985 × 126
#>    aid_data_record_id recommended_for_aggregates aid_data_parent_id umbrella
#>                 <int> <chr>                      <chr>              <chr>   
#>  1              94556 Yes                        NA                 No      
#>  2              94564 Yes                        NA                 No      
#>  3              94565 Yes                        NA                 No      
#>  4              94567 Yes                        NA                 No      
#>  5              94568 Yes                        NA                 No      
#>  6              94613 Yes                        NA                 No      
#>  7              94619 Yes                        NA                 No      
#>  8              95312 No                         NA                 No      
#>  9              95322 Yes                        NA                 No      
#> 10              95323 Yes                        NA                 No      
#> # ℹ 20,975 more rows
#> # ℹ 122 more variables: financier_country <chr>, recipient <chr>,
#> #   recipient_iso_3 <chr>, recipient_region <chr>, commitment_year <int>,
#> #   implementation_start_year <int>, completion_year <int>, title <chr>,
#> #   description <chr>, staff_comments <chr>, status <chr>, intent <chr>,
#> #   flow_type <chr>, flow_type_simplified <chr>,
#> #   oecd_oda_concessionality_threshold <dbl>, flow_class <chr>, …